summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--examples/client/inspect-channel.c4
-rw-r--r--examples/cm/callable/media-channel.c12
-rw-r--r--examples/cm/channelspecific/room.c8
-rw-r--r--examples/cm/contactlist/contact-list-manager.c24
-rw-r--r--telepathy-glib/base-connection-manager.c6
-rw-r--r--telepathy-glib/base-connection-manager.h2
-rw-r--r--telepathy-glib/channel-group.c14
-rw-r--r--telepathy-glib/channel-internal.h6
-rw-r--r--telepathy-glib/channel.h6
-rw-r--r--telepathy-glib/group-mixin.c34
-rw-r--r--telepathy-glib/group-mixin.h8
-rw-r--r--telepathy-glib/handle-repo.h8
-rw-r--r--telepathy-glib/handle-set.c30
-rw-r--r--telepathy-glib/intset.c108
-rw-r--r--telepathy-glib/intset.h58
-rw-r--r--telepathy-glib/message-mixin.c4
-rw-r--r--telepathy-glib/properties-mixin.c24
-rw-r--r--telepathy-glib/properties-mixin.h8
-rw-r--r--tests/dbus/call-cancellation.c6
-rw-r--r--tests/dbus/callable-example.c8
-rw-r--r--tests/dbus/cli-group.c6
-rw-r--r--tests/dbus/disconnection.c4
-rw-r--r--tests/dbus/group-mixin.c10
-rw-r--r--tests/dbus/handle-set.c2
-rw-r--r--tests/intset.c26
-rw-r--r--tests/lib/echo-cm.c2
-rw-r--r--tests/lib/params-cm.c2
-rw-r--r--tests/lib/simple-manager.c2
-rw-r--r--tests/lib/textchan-group.c2
29 files changed, 217 insertions, 217 deletions
diff --git a/examples/client/inspect-channel.c b/examples/client/inspect-channel.c
index fe2584f58..320c6b58c 100644
--- a/examples/client/inspect-channel.c
+++ b/examples/client/inspect-channel.c
@@ -59,8 +59,8 @@ channel_ready_cb (TpChannel *channel,
if (tp_proxy_has_interface_by_id (channel,
TP_IFACE_QUARK_CHANNEL_INTERFACE_GROUP))
{
- const TpIntSet *members = tp_channel_group_get_members (channel);
- TpIntSetFastIter group_iter;
+ const TpIntset *members = tp_channel_group_get_members (channel);
+ TpIntsetFastIter group_iter;
TpHandle member;
printf ("Group members:\n");
diff --git a/examples/cm/callable/media-channel.c b/examples/cm/callable/media-channel.c
index de76483f5..29dbe53a3 100644
--- a/examples/cm/callable/media-channel.c
+++ b/examples/cm/callable/media-channel.c
@@ -140,8 +140,8 @@ constructed (GObject *object)
TpBaseConnection *connection = tp_base_channel_get_connection (base_chan);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles
(connection, TP_HANDLE_TYPE_CONTACT);
- TpIntSet *members;
- TpIntSet *local_pending;
+ TpIntset *members;
+ TpIntset *local_pending;
gboolean requested;
if (chain_up != NULL)
@@ -301,7 +301,7 @@ example_callable_media_channel_close (ExampleCallableMediaChannel *self,
{
if (self->priv->progress != PROGRESS_ENDED)
{
- TpIntSet *everyone;
+ TpIntset *everyone;
self->priv->progress = PROGRESS_ENDED;
@@ -394,7 +394,7 @@ add_member (GObject *object,
tp_handle_set_is_member (self->group.local_pending, member))
{
/* We're in local-pending, move to members to accept. */
- TpIntSet *set = tp_intset_new_containing (member);
+ TpIntset *set = tp_intset_new_containing (member);
GHashTableIter iter;
gpointer v;
@@ -720,7 +720,7 @@ static gboolean
simulate_contact_answered_cb (gpointer p)
{
ExampleCallableMediaChannel *self = p;
- TpIntSet *peer_set;
+ TpIntset *peer_set;
GHashTableIter iter;
gpointer v;
TpHandleRepoIface *contact_repo;
@@ -928,7 +928,7 @@ media_request_streams (TpSvcChannelTypeStreamedMedia *iface,
if (self->priv->progress < PROGRESS_CALLING)
{
- TpIntSet *peer_set = tp_intset_new_containing (target);
+ TpIntset *peer_set = tp_intset_new_containing (target);
const gchar *peer;
g_message ("SIGNALLING: send: new streamed media call");
diff --git a/examples/cm/channelspecific/room.c b/examples/cm/channelspecific/room.c
index 2a25b611a..c55d929df 100644
--- a/examples/cm/channelspecific/room.c
+++ b/examples/cm/channelspecific/room.c
@@ -95,7 +95,7 @@ complete_join (ExampleCSHRoomChannel *self)
TpHandle alice_local, bob_local, chris_local, anon_local;
TpHandle alice_global, bob_global, chris_global;
TpGroupMixin *mixin = TP_GROUP_MIXIN (self);
- TpIntSet *added;
+ TpIntset *added;
/* For this example, we assume that all chatrooms initially contain
* Alice, Bob and Chris (and that their global IDs are also known),
@@ -128,8 +128,8 @@ complete_join (ExampleCSHRoomChannel *self)
mixin->self_handle == anon_local)
{
TpHandle new_self;
- TpIntSet *rp = tp_intset_new ();
- TpIntSet *removed = tp_intset_new ();
+ TpIntset *rp = tp_intset_new ();
+ TpIntset *removed = tp_intset_new ();
str = g_strdup_printf ("renamed by server@%s", room_name);
new_self = tp_handle_ensure (contact_repo, str, NULL, NULL);
@@ -193,7 +193,7 @@ join_room (ExampleCSHRoomChannel *self)
TpBaseConnection *conn = tp_base_channel_get_connection (TP_BASE_CHANNEL (self));
TpGroupMixin *mixin = TP_GROUP_MIXIN (self);
GObject *object = (GObject *) self;
- TpIntSet *add_remote_pending;
+ TpIntset *add_remote_pending;
g_assert (!tp_handle_set_is_member (mixin->members, mixin->self_handle));
g_assert (!tp_handle_set_is_member (mixin->remote_pending,
diff --git a/examples/cm/contactlist/contact-list-manager.c b/examples/cm/contactlist/contact-list-manager.c
index 900d9adf0..d14e26b9e 100644
--- a/examples/cm/contactlist/contact-list-manager.c
+++ b/examples/cm/contactlist/contact-list-manager.c
@@ -378,8 +378,8 @@ receive_contact_lists (gpointer p)
ExampleContactListManager *self = p;
TpHandle handle, cambridge, montreal, francophones;
ExampleContactDetails *d;
- TpIntSet *set, *cam_set, *mtl_set, *fr_set;
- TpIntSetFastIter iter;
+ TpIntset *set, *cam_set, *mtl_set, *fr_set;
+ TpIntsetFastIter iter;
ExampleContactList *subscribe, *publish, *stored;
ExampleContactGroup *cambridge_group, *montreal_group,
*francophones_group;
@@ -1032,8 +1032,8 @@ send_updated_roster (ExampleContactListManager *self,
}
else
{
- TpIntSet *set = tp_handle_set_peek (d->tags);
- TpIntSetFastIter iter;
+ TpIntset *set = tp_handle_set_peek (d->tags);
+ TpIntsetFastIter iter;
TpHandle member;
tp_intset_fast_iter_init (&iter, set);
@@ -1071,7 +1071,7 @@ example_contact_list_manager_add_to_group (ExampleContactListManager *self,
if (updated)
{
- TpIntSet *added = tp_intset_new_containing (member);
+ TpIntset *added = tp_intset_new_containing (member);
send_updated_roster (self, member);
tp_group_mixin_change_members (channel, "", added, NULL, NULL, NULL,
@@ -1102,7 +1102,7 @@ example_contact_list_manager_remove_from_group (
if (tp_handle_set_remove (d->tags, group))
{
- TpIntSet *removed = tp_intset_new_containing (member);
+ TpIntset *removed = tp_intset_new_containing (member);
send_updated_roster (self, member);
tp_group_mixin_change_members (channel, "", NULL, removed, NULL, NULL,
@@ -1145,7 +1145,7 @@ receive_auth_request (ExampleContactListManager *self,
TpHandle contact)
{
ExampleContactDetails *d;
- TpIntSet *set;
+ TpIntset *set;
ExampleContactList *publish = self->priv->lists[
EXAMPLE_CONTACT_LIST_PUBLISH];
ExampleContactList *stored = self->priv->lists[
@@ -1186,7 +1186,7 @@ receive_authorized (gpointer p)
{
SelfAndContact *s = p;
ExampleContactDetails *d;
- TpIntSet *set;
+ TpIntset *set;
ExampleContactList *subscribe = s->self->priv->lists[
EXAMPLE_CONTACT_LIST_SUBSCRIBE];
ExampleContactList *stored = s->self->priv->lists[
@@ -1236,7 +1236,7 @@ receive_unauthorized (gpointer p)
{
SelfAndContact *s = p;
ExampleContactDetails *d;
- TpIntSet *set;
+ TpIntset *set;
ExampleContactList *subscribe = s->self->priv->lists[
EXAMPLE_CONTACT_LIST_SUBSCRIBE];
@@ -1280,7 +1280,7 @@ example_contact_list_manager_add_to_list (ExampleContactListManager *self,
const gchar *message,
GError **error)
{
- TpIntSet *set;
+ TpIntset *set;
ExampleContactList *stored = self->priv->lists[EXAMPLE_CONTACT_LIST_STORED];
switch (list)
@@ -1422,7 +1422,7 @@ example_contact_list_manager_remove_from_list (ExampleContactListManager *self,
const gchar *message,
GError **error)
{
- TpIntSet *set;
+ TpIntset *set;
switch (list)
{
@@ -1625,7 +1625,7 @@ example_contact_list_manager_set_alias (ExampleContactListManager *self,
ExampleContactList *stored = self->priv->lists[
EXAMPLE_CONTACT_LIST_STORED];
gchar *old = d->alias;
- TpIntSet *set;
+ TpIntset *set;
/* FIXME: if stored list hasn't been retrieved yet, queue the change for
* later */
diff --git a/telepathy-glib/base-connection-manager.c b/telepathy-glib/base-connection-manager.c
index 4e51b2979..42c9a5899 100644
--- a/telepathy-glib/base-connection-manager.c
+++ b/telepathy-glib/base-connection-manager.c
@@ -104,7 +104,7 @@ _tp_legacy_protocol_get_parameters (TpBaseProtocol *protocol)
}
static gboolean parse_parameters (const TpCMParamSpec *paramspec,
- GHashTable *provided, TpIntSet *params_present,
+ GHashTable *provided, TpIntset *params_present,
const TpCMParamSetter set_param, void *params, GError **error);
static TpBaseConnection *
@@ -117,7 +117,7 @@ _tp_legacy_protocol_new_connection (TpBaseProtocol *protocol,
TpBaseConnectionManagerClass *cls;
TpBaseConnection *conn = NULL;
void *params = NULL;
- TpIntSet *params_present = NULL;
+ TpIntset *params_present = NULL;
TpCMParamSetter set_param;
if (self->cm == NULL)
@@ -814,7 +814,7 @@ set_param_from_value (const TpCMParamSpec *paramspec,
static gboolean
parse_parameters (const TpCMParamSpec *paramspec,
GHashTable *provided,
- TpIntSet *params_present,
+ TpIntset *params_present,
const TpCMParamSetter set_param,
void *params,
GError **error)
diff --git a/telepathy-glib/base-connection-manager.h b/telepathy-glib/base-connection-manager.h
index d3471b8b0..6fd8f305b 100644
--- a/telepathy-glib/base-connection-manager.h
+++ b/telepathy-glib/base-connection-manager.h
@@ -57,7 +57,7 @@ typedef struct _TpBaseConnectionManagerClassPrivate
typedef TpBaseConnection *(*TpBaseConnectionManagerNewConnFunc)(
TpBaseConnectionManager *self, const gchar *proto,
- TpIntSet *params_present, void *parsed_params, GError **error);
+ TpIntset *params_present, void *parsed_params, GError **error);
struct _TpBaseConnectionManagerClass {
GObjectClass parent_class;
diff --git a/telepathy-glib/channel-internal.h b/telepathy-glib/channel-internal.h
index c3682b950..4e4bcf67f 100644
--- a/telepathy-glib/channel-internal.h
+++ b/telepathy-glib/channel-internal.h
@@ -58,9 +58,9 @@ struct _TpChannelPrivate {
TpHandle group_self_handle;
TpChannelGroupFlags group_flags;
/* NULL if members not discovered yet */
- TpIntSet *group_members;
- TpIntSet *group_local_pending;
- TpIntSet *group_remote_pending;
+ TpIntset *group_members;
+ TpIntset *group_local_pending;
+ TpIntset *group_remote_pending;
/* (TpHandle => LocalPendingInfo), or NULL if members not discovered yet */
GHashTable *group_local_pending_info;
diff --git a/telepathy-glib/channel.h b/telepathy-glib/channel.h
index e1a89fb2a..4839b0e69 100644
--- a/telepathy-glib/channel.h
+++ b/telepathy-glib/channel.h
@@ -105,9 +105,9 @@ GHashTable *tp_channel_borrow_immutable_properties (TpChannel *self);
TpHandle tp_channel_group_get_self_handle (TpChannel *self);
TpChannelGroupFlags tp_channel_group_get_flags (TpChannel *self);
-const TpIntSet *tp_channel_group_get_members (TpChannel *self);
-const TpIntSet *tp_channel_group_get_local_pending (TpChannel *self);
-const TpIntSet *tp_channel_group_get_remote_pending (TpChannel *self);
+const TpIntset *tp_channel_group_get_members (TpChannel *self);
+const TpIntset *tp_channel_group_get_local_pending (TpChannel *self);
+const TpIntset *tp_channel_group_get_remote_pending (TpChannel *self);
gboolean tp_channel_group_get_local_pending_info (TpChannel *self,
TpHandle local_pending, TpHandle *actor,
TpChannelGroupChangeReason *reason, const gchar **message);
diff --git a/telepathy-glib/group-mixin.h b/telepathy-glib/group-mixin.h
index 655e64f03..772030568 100644
--- a/telepathy-glib/group-mixin.h
+++ b/telepathy-glib/group-mixin.h
@@ -202,12 +202,12 @@ gboolean tp_group_mixin_get_handle_owners (GObject *obj,
void tp_group_mixin_change_flags (GObject *obj,
TpChannelGroupFlags add, TpChannelGroupFlags del);
gboolean tp_group_mixin_change_members (GObject *obj,
- const gchar *message, const TpIntSet *add, const TpIntSet *del,
- const TpIntSet *add_local_pending, const TpIntSet *add_remote_pending,
+ const gchar *message, const TpIntset *add, const TpIntset *del,
+ const TpIntset *add_local_pending, const TpIntset *add_remote_pending,
TpHandle actor, TpChannelGroupChangeReason reason);
gboolean tp_group_mixin_change_members_detailed (GObject *obj,
- const TpIntSet *add, const TpIntSet *del,
- const TpIntSet *add_local_pending, const TpIntSet *add_remote_pending,
+ const TpIntset *add, const TpIntset *del,
+ const TpIntset *add_local_pending, const TpIntset *add_remote_pending,
const GHashTable *details);
void tp_group_mixin_change_self_handle (GObject *obj,
TpHandle new_self_handle);
diff --git a/telepathy-glib/handle-repo.h b/telepathy-glib/handle-repo.h
index 908d79771..4fe996764 100644
--- a/telepathy-glib/handle-repo.h
+++ b/telepathy-glib/handle-repo.h
@@ -118,7 +118,7 @@ TpHandleSet *tp_handle_set_copy (const TpHandleSet *other)
void tp_handle_set_clear (TpHandleSet *set);
void tp_handle_set_destroy (TpHandleSet *set);
-TpIntSet *tp_handle_set_peek (TpHandleSet *set) G_GNUC_WARN_UNUSED_RESULT;
+TpIntset *tp_handle_set_peek (TpHandleSet *set) G_GNUC_WARN_UNUSED_RESULT;
void tp_handle_set_add (TpHandleSet *set, TpHandle handle);
gboolean tp_handle_set_remove (TpHandleSet *set, TpHandle handle);
@@ -134,10 +134,10 @@ GArray *tp_handle_set_to_array (const TpHandleSet *set)
TpHandleSet *tp_handle_set_new_from_array (TpHandleRepoIface *repo,
const GArray *array) G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_handle_set_update (TpHandleSet *set, const TpIntSet *add)
+TpIntset *tp_handle_set_update (TpHandleSet *set, const TpIntset *add)
G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_handle_set_difference_update (TpHandleSet *set,
- const TpIntSet *remove) G_GNUC_WARN_UNUSED_RESULT;
+TpIntset *tp_handle_set_difference_update (TpHandleSet *set,
+ const TpIntset *remove) G_GNUC_WARN_UNUSED_RESULT;
/* static inline because it relies on NUM_TP_HANDLE_TYPES */
/**
diff --git a/telepathy-glib/handle-set.c b/telepathy-glib/handle-set.c
index a498f769c..ce6c6d076 100644
--- a/telepathy-glib/handle-set.c
+++ b/telepathy-glib/handle-set.c
@@ -32,13 +32,13 @@
/**
* TpHandleSet:
*
- * A set of handles. This is similar to a #TpIntSet (and implemented using
+ * A set of handles. This is similar to a #TpIntset (and implemented using
* one), but adding a handle to the set also references it.
*/
struct _TpHandleSet
{
TpHandleRepoIface *repo;
- TpIntSet *intset;
+ TpIntset *intset;
};
/**
@@ -102,7 +102,7 @@ tp_handle_set_new_from_array (TpHandleRepoIface *repo,
const GArray *array)
{
TpHandleSet *set = tp_handle_set_new (repo);
- TpIntSet *tmp = tp_intset_from_array (array);
+ TpIntset *tmp = tp_intset_from_array (array);
tp_intset_destroy (tp_handle_set_update (set, tmp));
tp_intset_destroy (tmp);
@@ -167,9 +167,9 @@ tp_handle_set_is_empty (const TpHandleSet *set)
*
* <!--Returns: says it all, this comment is just to keep gtkdoc happy-->
*
- * Returns: (transfer none): the underlying #TpIntSet used by this #TpHandleSet
+ * Returns: (transfer none): the underlying #TpIntset used by this #TpHandleSet
*/
-TpIntSet *
+TpIntset *
tp_handle_set_peek (TpHandleSet *set)
{
return set->intset;
@@ -350,17 +350,17 @@ tp_handle_set_copy (const TpHandleSet *other)
/**
* tp_handle_set_update: (skip)
* @set: a #TpHandleSet to update
- * @add: a #TpIntSet of handles to add
+ * @add: a #TpIntset of handles to add
*
* Add a set of handles to a handle set, referencing those which are not
- * already members. The TpIntSet returned must be freed with tp_intset_destroy.
+ * already members. The TpIntset returned must be freed with tp_intset_destroy.
*
* Returns: the handles which were added (some subset of @add)
*/
-TpIntSet *
-tp_handle_set_update (TpHandleSet *set, const TpIntSet *add)
+TpIntset *
+tp_handle_set_update (TpHandleSet *set, const TpIntset *add)
{
- TpIntSet *ret, *tmp;
+ TpIntset *ret, *tmp;
g_return_val_if_fail (set != NULL, NULL);
g_return_val_if_fail (add != NULL, NULL);
@@ -387,10 +387,10 @@ unref_one (guint handle, gpointer data)
/**
* tp_handle_set_difference_update: (skip)
* @set: a #TpHandleSet to update
- * @remove: a #TpIntSet of handles to remove
+ * @remove: a #TpIntset of handles to remove
*
* Remove a set of handles from a handle set, dereferencing those which are
- * members. The TpIntSet returned must be freed with tp_intset_destroy.
+ * members. The TpIntset returned must be freed with tp_intset_destroy.
*
* If you want to be able to inspect the handles in the set returned,
* you must ensure that this function does not cause their refcount to drop
@@ -401,10 +401,10 @@ unref_one (guint handle, gpointer data)
* Returns: the handles which were dereferenced and removed (some subset
* of @remove).
*/
-TpIntSet *
-tp_handle_set_difference_update (TpHandleSet *set, const TpIntSet *remove)
+TpIntset *
+tp_handle_set_difference_update (TpHandleSet *set, const TpIntset *remove)
{
- TpIntSet *ret, *tmp;
+ TpIntset *ret, *tmp;
g_return_val_if_fail (set != NULL, NULL);
g_return_val_if_fail (remove != NULL, NULL);
diff --git a/telepathy-glib/intset.c b/telepathy-glib/intset.c
index f35b09a87..55d6fcafe 100644
--- a/telepathy-glib/intset.c
+++ b/telepathy-glib/intset.c
@@ -103,7 +103,7 @@ tp_intset_get_type (void)
* A structure representing iteration over a set of integers. Must be
* initialized with either TP_INTSET_ITER_INIT() or tp_intset_iter_init().
*
- * Since 0.11.6, consider using #TpIntSetFastIter if iteration in
+ * Since 0.11.6, consider using #TpIntsetFastIter if iteration in
* numerical order is not required.
*
* Before 0.11.UNRELEASED, this type was called <type>TpIntSetIter</type>,
@@ -115,18 +115,18 @@ tp_intset_get_type (void)
* TP_INTSET_ITER_INIT:
* @set: A set of integers
*
- * A suitable static initializer for a #TpIntSetIter, to be used as follows:
+ * A suitable static initializer for a #TpIntsetIter, to be used as follows:
*
* <informalexample><programlisting>
* void
- * do_something (const TpIntSet *intset)
+ * do_something (const TpIntset *intset)
* {
- * TpIntSetIter iter = TP_INTSET_ITER_INIT (intset);
+ * TpIntsetIter iter = TP_INTSET_ITER_INIT (intset);
* /<!-- -->* ... do something with iter ... *<!-- -->/
* }
* </programlisting></informalexample>
*
- * Since 0.11.6, consider using #TpIntSetFastIter if iteration in
+ * Since 0.11.6, consider using #TpIntsetFastIter if iteration in
* numerical order is not required.
*
*/
@@ -176,11 +176,11 @@ struct _TpIntset
*
* We could use g_bit_nth_msf (value, BITFIELD_BITS) instead of LOW_MASK if we
* wanted to get largest_ever exactly right, but we just need something
- * reasonable to make TpIntSetIter terminate early, and carrying on for up to
+ * reasonable to make TpIntsetIter terminate early, and carrying on for up to
* BITFIELD_BITS extra iterations isn't a problem.
*/
static inline void
-intset_update_largest_ever (TpIntSet *set,
+intset_update_largest_ever (TpIntset *set,
gpointer key)
{
guint upper_bound = GPOINTER_TO_UINT (key) | LOW_MASK;
@@ -198,7 +198,7 @@ intset_update_largest_ever (TpIntSet *set,
*
* Returns: a new, empty integer set to be destroyed with tp_intset_destroy()
*/
-TpIntSet *
+TpIntset *
tp_intset_sized_new (guint size G_GNUC_UNUSED)
{
return tp_intset_new ();
@@ -211,10 +211,10 @@ tp_intset_sized_new (guint size G_GNUC_UNUSED)
*
* Returns: a new, empty integer set to be destroyed with tp_intset_destroy()
*/
-TpIntSet *
+TpIntset *
tp_intset_new ()
{
- TpIntSet *set = g_slice_new (TpIntSet);
+ TpIntset *set = g_slice_new (TpIntset);
set->table = g_hash_table_new (NULL, NULL);
set->largest_ever = 0;
@@ -232,10 +232,10 @@ tp_intset_new ()
*
* @since 0.7.26
*/
-TpIntSet *
+TpIntset *
tp_intset_new_containing (guint element)
{
- TpIntSet *ret = tp_intset_new ();
+ TpIntset *ret = tp_intset_new ();
tp_intset_add (ret, element);
@@ -249,12 +249,12 @@ tp_intset_new_containing (guint element)
* Free all memory used by the set.
*/
void
-tp_intset_destroy (TpIntSet *set)
+tp_intset_destroy (TpIntset *set)
{
g_return_if_fail (set != NULL);
g_hash_table_destroy (set->table);
- g_slice_free (TpIntSet, set);
+ g_slice_free (TpIntset, set);
}
/**
@@ -264,7 +264,7 @@ tp_intset_destroy (TpIntSet *set)
* Unset every integer in the set.
*/
void
-tp_intset_clear (TpIntSet *set)
+tp_intset_clear (TpIntset *set)
{
g_return_if_fail (set != NULL);
@@ -276,10 +276,10 @@ tp_intset_clear (TpIntSet *set)
* @set: set
* @element: integer to add
*
- * Add an integer into a TpIntSet.
+ * Add an integer into a TpIntset.
*/
void
-tp_intset_add (TpIntSet *set,
+tp_intset_add (TpIntset *set,
guint element)
{
gpointer key = GSIZE_TO_POINTER ((gsize) HIGH_PART (element));
@@ -303,12 +303,12 @@ tp_intset_add (TpIntSet *set,
* @set: set
* @element: integer to add
*
- * Remove an integer from a TpIntSet
+ * Remove an integer from a TpIntset
*
* Returns: %TRUE if @element was previously in @set
*/
gboolean
-tp_intset_remove (TpIntSet *set,
+tp_intset_remove (TpIntset *set,
guint element)
{
gpointer key = GSIZE_TO_POINTER ((gsize) HIGH_PART (element));
@@ -334,7 +334,7 @@ tp_intset_remove (TpIntSet *set,
}
static inline gboolean
-_tp_intset_is_member (const TpIntSet *set,
+_tp_intset_is_member (const TpIntset *set,
guint element)
{
gpointer key = GSIZE_TO_POINTER ((gsize) HIGH_PART (element));
@@ -355,7 +355,7 @@ _tp_intset_is_member (const TpIntSet *set,
* Returns: %TRUE if @element is in @set
*/
gboolean
-tp_intset_is_member (const TpIntSet *set, guint element)
+tp_intset_is_member (const TpIntset *set, guint element)
{
g_return_val_if_fail (set != NULL, FALSE);
@@ -372,7 +372,7 @@ tp_intset_is_member (const TpIntSet *set, guint element)
*/
void
-tp_intset_foreach (const TpIntSet *set,
+tp_intset_foreach (const TpIntset *set,
TpIntFunc func,
gpointer userdata)
{
@@ -418,7 +418,7 @@ addint (guint i, gpointer data)
* be freed by the caller) containing the same integers as @set.
*/
GArray *
-tp_intset_to_array (const TpIntSet *set)
+tp_intset_to_array (const TpIntset *set)
{
GArray *array;
@@ -441,10 +441,10 @@ tp_intset_to_array (const TpIntSet *set)
* Returns: A set containing the same integers as @array.
*/
-TpIntSet *
+TpIntset *
tp_intset_from_array (const GArray *array)
{
- TpIntSet *set;
+ TpIntset *set;
guint i;
g_return_val_if_fail (array != NULL, NULL);
@@ -479,7 +479,7 @@ count_bits32 (guint32 n)
*/
guint
-tp_intset_size (const TpIntSet *set)
+tp_intset_size (const TpIntset *set)
{
guint count = 0;
gpointer entry;
@@ -509,7 +509,7 @@ tp_intset_size (const TpIntSet *set)
* Since: 0.11.6
*/
gboolean
-tp_intset_is_empty (const TpIntSet *set)
+tp_intset_is_empty (const TpIntset *set)
{
g_return_val_if_fail (set != NULL, TRUE);
return (g_hash_table_size (set->table) == 0);
@@ -526,8 +526,8 @@ tp_intset_is_empty (const TpIntSet *set)
*/
gboolean
-tp_intset_is_equal (const TpIntSet *left,
- const TpIntSet *right)
+tp_intset_is_equal (const TpIntset *left,
+ const TpIntset *right)
{
gpointer key, value;
GHashTableIter iter;
@@ -562,12 +562,12 @@ tp_intset_is_equal (const TpIntSet *left,
* tp_intset_destroy() by the caller
*/
-TpIntSet *
-tp_intset_copy (const TpIntSet *orig)
+TpIntset *
+tp_intset_copy (const TpIntset *orig)
{
gpointer key, value;
GHashTableIter iter;
- TpIntSet *ret;
+ TpIntset *ret;
g_return_val_if_fail (orig != NULL, NULL);
@@ -597,12 +597,12 @@ tp_intset_copy (const TpIntSet *orig)
* tp_intset_destroy() by the caller
*/
-TpIntSet *
-tp_intset_intersection (const TpIntSet *left, const TpIntSet *right)
+TpIntset *
+tp_intset_intersection (const TpIntset *left, const TpIntset *right)
{
gpointer key, value;
GHashTableIter iter;
- TpIntSet *ret;
+ TpIntset *ret;
ret = tp_intset_new ();
@@ -637,12 +637,12 @@ tp_intset_intersection (const TpIntSet *left, const TpIntSet *right)
* tp_intset_destroy() by the caller
*/
-TpIntSet *
-tp_intset_union (const TpIntSet *left, const TpIntSet *right)
+TpIntset *
+tp_intset_union (const TpIntset *left, const TpIntset *right)
{
gpointer key, value;
GHashTableIter iter;
- TpIntSet *ret;
+ TpIntset *ret;
ret = tp_intset_copy (left);
@@ -673,10 +673,10 @@ tp_intset_union (const TpIntSet *left, const TpIntSet *right)
* tp_intset_destroy() by the caller
*/
-TpIntSet *
-tp_intset_difference (const TpIntSet *left, const TpIntSet *right)
+TpIntset *
+tp_intset_difference (const TpIntset *left, const TpIntset *right)
{
- TpIntSet *ret;
+ TpIntset *ret;
gpointer key, value;
GHashTableIter iter;
@@ -716,10 +716,10 @@ tp_intset_difference (const TpIntSet *left, const TpIntSet *right)
* with tp_intset_destroy() by the caller
*/
-TpIntSet *
-tp_intset_symmetric_difference (const TpIntSet *left, const TpIntSet *right)
+TpIntset *
+tp_intset_symmetric_difference (const TpIntset *left, const TpIntset *right)
{
- TpIntSet *ret;
+ TpIntset *ret;
gpointer key, value;
GHashTableIter iter;
@@ -767,7 +767,7 @@ _dump_foreach (guint i, gpointer data)
* numbers in @set in a human-readable format
*/
gchar *
-tp_intset_dump (const TpIntSet *set)
+tp_intset_dump (const TpIntset *set)
{
GString *tmp = g_string_new ("");
@@ -785,20 +785,20 @@ tp_intset_dump (const TpIntSet *set)
* Usage:
*
* <informalexample><programlisting>
- * TpIntSetIter iter = TP_INTSET_INIT (intset);
+ * TpIntsetIter iter = TP_INTSET_INIT (intset);
* while (tp_intset_iter_next (&amp;iter))
* {
* printf ("%u is in the intset\n", iter.element);
* }
* </programlisting></informalexample>
*
- * Since 0.11.6, consider using #TpIntSetFastIter if iteration in
+ * Since 0.11.6, consider using #TpIntsetFastIter if iteration in
* numerical order is not required.
*
* Returns: %TRUE if (@iter->element) has been advanced
*/
gboolean
-tp_intset_iter_next (TpIntSetIter *iter)
+tp_intset_iter_next (TpIntsetIter *iter)
{
g_return_val_if_fail (iter != NULL, FALSE);
g_return_val_if_fail (iter->set != NULL, FALSE);
@@ -826,7 +826,7 @@ tp_intset_iter_next (TpIntSetIter *iter)
}
/**
- * TpIntSetFastIter:
+ * TpIntsetFastIter:
*
* An opaque structure representing iteration in undefined order over a set of
* integers. Must be initialized with tp_intset_fast_iter_init().
@@ -837,7 +837,7 @@ tp_intset_iter_next (TpIntSetIter *iter)
* Usage is similar to #GHashTableIter:
*
* <informalexample><programlisting>
- * TpIntSetFastIter iter;
+ * TpIntsetFastIter iter;
* guint element;
*
* tp_intset_fast_iter_init (&amp;iter, intset);
@@ -858,7 +858,7 @@ typedef struct {
gsize bitfield;
} RealFastIter;
-G_STATIC_ASSERT (sizeof (TpIntSetFastIter) >= sizeof (RealFastIter));
+G_STATIC_ASSERT (sizeof (TpIntsetFastIter) >= sizeof (RealFastIter));
/**
* tp_intset_fast_iter_init:
@@ -871,8 +871,8 @@ G_STATIC_ASSERT (sizeof (TpIntSetFastIter) >= sizeof (RealFastIter));
* Since: 0.11.6
*/
void
-tp_intset_fast_iter_init (TpIntSetFastIter *iter,
- const TpIntSet *set)
+tp_intset_fast_iter_init (TpIntsetFastIter *iter,
+ const TpIntset *set)
{
RealFastIter *real = (RealFastIter *) iter;
g_return_if_fail (set != NULL);
@@ -897,7 +897,7 @@ tp_intset_fast_iter_init (TpIntSetFastIter *iter,
* Since: 0.11.6
*/
gboolean
-tp_intset_fast_iter_next (TpIntSetFastIter *iter,
+tp_intset_fast_iter_next (TpIntsetFastIter *iter,
guint *output)
{
RealFastIter *real = (RealFastIter *) iter;
diff --git a/telepathy-glib/intset.h b/telepathy-glib/intset.h
index 0336ace81..30fd30165 100644
--- a/telepathy-glib/intset.h
+++ b/telepathy-glib/intset.h
@@ -44,42 +44,42 @@ typedef TpIntset TpIntSet;
typedef void (*TpIntFunc) (guint i, gpointer userdata);
-TpIntSet *tp_intset_new (void) G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_intset_sized_new (guint size) G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_intset_new_containing (guint element) G_GNUC_WARN_UNUSED_RESULT;
-void tp_intset_destroy (TpIntSet *set);
-void tp_intset_clear (TpIntSet *set);
-
-void tp_intset_add (TpIntSet *set, guint element);
-gboolean tp_intset_remove (TpIntSet *set, guint element);
-gboolean tp_intset_is_member (const TpIntSet *set, guint element)
+TpIntset *tp_intset_new (void) G_GNUC_WARN_UNUSED_RESULT;
+TpIntset *tp_intset_sized_new (guint size) G_GNUC_WARN_UNUSED_RESULT;
+TpIntset *tp_intset_new_containing (guint element) G_GNUC_WARN_UNUSED_RESULT;
+void tp_intset_destroy (TpIntset *set);
+void tp_intset_clear (TpIntset *set);
+
+void tp_intset_add (TpIntset *set, guint element);
+gboolean tp_intset_remove (TpIntset *set, guint element);
+gboolean tp_intset_is_member (const TpIntset *set, guint element)
G_GNUC_WARN_UNUSED_RESULT;
-void tp_intset_foreach (const TpIntSet *set, TpIntFunc func,
+void tp_intset_foreach (const TpIntset *set, TpIntFunc func,
gpointer userdata);
-GArray *tp_intset_to_array (const TpIntSet *set) G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_intset_from_array (const GArray *array) G_GNUC_WARN_UNUSED_RESULT;
+GArray *tp_intset_to_array (const TpIntset *set) G_GNUC_WARN_UNUSED_RESULT;
+TpIntset *tp_intset_from_array (const GArray *array) G_GNUC_WARN_UNUSED_RESULT;
-gboolean tp_intset_is_empty (const TpIntSet *set) G_GNUC_WARN_UNUSED_RESULT;
-guint tp_intset_size (const TpIntSet *set) G_GNUC_WARN_UNUSED_RESULT;
+gboolean tp_intset_is_empty (const TpIntset *set) G_GNUC_WARN_UNUSED_RESULT;
+guint tp_intset_size (const TpIntset *set) G_GNUC_WARN_UNUSED_RESULT;
-gboolean tp_intset_is_equal (const TpIntSet *left, const TpIntSet *right)
+gboolean tp_intset_is_equal (const TpIntset *left, const TpIntset *right)
G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_intset_copy (const TpIntSet *orig) G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_intset_intersection (const TpIntSet *left, const TpIntSet *right)
+TpIntset *tp_intset_copy (const TpIntset *orig) G_GNUC_WARN_UNUSED_RESULT;
+TpIntset *tp_intset_intersection (const TpIntset *left, const TpIntset *right)
G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_intset_union (const TpIntSet *left, const TpIntSet *right)
+TpIntset *tp_intset_union (const TpIntset *left, const TpIntset *right)
G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_intset_difference (const TpIntSet *left, const TpIntSet *right)
+TpIntset *tp_intset_difference (const TpIntset *left, const TpIntset *right)
G_GNUC_WARN_UNUSED_RESULT;
-TpIntSet *tp_intset_symmetric_difference (const TpIntSet *left,
- const TpIntSet *right) G_GNUC_WARN_UNUSED_RESULT;
+TpIntset *tp_intset_symmetric_difference (const TpIntset *left,
+ const TpIntset *right) G_GNUC_WARN_UNUSED_RESULT;
-gchar *tp_intset_dump (const TpIntSet *set) G_GNUC_WARN_UNUSED_RESULT;
+gchar *tp_intset_dump (const TpIntset *set) G_GNUC_WARN_UNUSED_RESULT;
typedef struct {
- const TpIntSet *set;
+ const TpIntset *set;
guint element;
} TpIntsetIter;
@@ -95,7 +95,7 @@ typedef TpIntsetIter TpIntSetIter;
#define tp_intset_iter_init(iter, set) tp_intset_iter_init_inline (iter, set)
static inline void
-tp_intset_iter_init_inline (TpIntSetIter *iter, const TpIntSet *set)
+tp_intset_iter_init_inline (TpIntsetIter *iter, const TpIntset *set)
{
g_return_if_fail (iter != NULL);
iter->set = set;
@@ -104,14 +104,14 @@ tp_intset_iter_init_inline (TpIntSetIter *iter, const TpIntSet *set)
#define tp_intset_iter_reset(iter) tp_intset_iter_reset_inline (iter)
static inline void
-tp_intset_iter_reset_inline (TpIntSetIter *iter)
+tp_intset_iter_reset_inline (TpIntsetIter *iter)
{
g_return_if_fail (iter != NULL);
g_return_if_fail (iter->set != NULL);
iter->element = (guint)(-1);
}
-gboolean tp_intset_iter_next (TpIntSetIter *iter);
+gboolean tp_intset_iter_next (TpIntsetIter *iter);
typedef struct {
/*<private>*/
@@ -126,10 +126,10 @@ typedef struct {
*/
typedef TpIntsetFastIter TpIntSetFastIter;
-void tp_intset_fast_iter_init (TpIntSetFastIter *iter,
- const TpIntSet *set);
+void tp_intset_fast_iter_init (TpIntsetFastIter *iter,
+ const TpIntset *set);
-gboolean tp_intset_fast_iter_next (TpIntSetFastIter *iter,
+gboolean tp_intset_fast_iter_next (TpIntsetFastIter *iter,
guint *output);
G_END_DECLS
diff --git a/telepathy-glib/message-mixin.c b/telepathy-glib/message-mixin.c
index 972df4db2..fc5fec7cb 100644
--- a/telepathy-glib/message-mixin.c
+++ b/telepathy-glib/message-mixin.c
@@ -393,9 +393,9 @@ tp_message_ref_handle (TpMessage *self,
static void
tp_message_ref_handles (TpMessage *self,
TpHandleType handle_type,
- TpIntSet *handles)
+ TpIntset *handles)
{
- TpIntSet *updated;
+ TpIntset *updated;
g_return_if_fail (handle_type > TP_HANDLE_TYPE_NONE);
g_return_if_fail (handle_type < NUM_TP_HANDLE_TYPES);
diff --git a/telepathy-glib/properties-mixin.c b/telepathy-glib/properties-mixin.c
index 17b93b1ca..8f22acd58 100644
--- a/telepathy-glib/properties-mixin.c
+++ b/telepathy-glib/properties-mixin.c
@@ -64,7 +64,7 @@ struct _TpPropertiesContext {
TpPropertiesMixin *mixin;
DBusGMethodInvocation *dbus_ctx;
- TpIntSet *remaining;
+ TpIntset *remaining;
GValue **values;
};
@@ -623,7 +623,7 @@ void
tp_properties_context_return (TpPropertiesContext *ctx, GError *error)
{
GObject *obj = ctx->mixin->priv->object;
- TpIntSet *changed_props_val, *changed_props_flags;
+ TpIntset *changed_props_val, *changed_props_flags;
guint i;
DEBUG ("%s", (error) ? "failure" : "success");
@@ -744,7 +744,7 @@ values_are_equal (const GValue *v1, const GValue *v2)
* @obj: An object with the properties mixin
* @prop_id: A property ID on which to act
* @new_value: Property value
- * @props: either %NULL, or a pointer to a TpIntSet
+ * @props: either %NULL, or a pointer to a TpIntset
*
* Change the value of the given property ID in response to a server state
* change.
@@ -763,7 +763,7 @@ void
tp_properties_mixin_change_value (GObject *obj,
guint prop_id,
const GValue *new_value,
- TpIntSet *props)
+ TpIntset *props)
{
TpPropertiesMixin *mixin = TP_PROPERTIES_MIXIN (obj);
TpPropertiesMixinClass *mixin_cls = TP_PROPERTIES_MIXIN_CLASS (
@@ -792,7 +792,7 @@ tp_properties_mixin_change_value (GObject *obj,
}
else
{
- TpIntSet *changed_props = tp_intset_sized_new (prop_id + 1);
+ TpIntset *changed_props = tp_intset_sized_new (prop_id + 1);
tp_intset_add (changed_props, prop_id);
tp_properties_mixin_emit_changed (obj, changed_props);
@@ -807,7 +807,7 @@ tp_properties_mixin_change_value (GObject *obj,
* @prop_id: A property ID on which to act
* @add: Property flags to be added via bitwise OR
* @del: Property flags to be removed via bitwise AND
- * @props: either %NULL, or a pointer to a TpIntSet
+ * @props: either %NULL, or a pointer to a TpIntset
*
* Change the flags for the given property ID in response to a server state
* change.
@@ -827,7 +827,7 @@ tp_properties_mixin_change_flags (GObject *obj,
guint prop_id,
TpPropertyFlags add,
TpPropertyFlags del,
- TpIntSet *props)
+ TpIntset *props)
{
TpPropertiesMixin *mixin = TP_PROPERTIES_MIXIN (obj);
TpPropertiesMixinClass *mixin_cls = TP_PROPERTIES_MIXIN_CLASS (
@@ -853,7 +853,7 @@ tp_properties_mixin_change_flags (GObject *obj,
}
else
{
- TpIntSet *changed_props = tp_intset_sized_new (prop_id + 1);
+ TpIntset *changed_props = tp_intset_sized_new (prop_id + 1);
tp_intset_add (changed_props, prop_id);
tp_properties_mixin_emit_flags (obj, changed_props);
@@ -871,14 +871,14 @@ tp_properties_mixin_change_flags (GObject *obj,
* added using their stored values.
*/
void
-tp_properties_mixin_emit_changed (GObject *obj, const TpIntSet *props)
+tp_properties_mixin_emit_changed (GObject *obj, const TpIntset *props)
{
TpPropertiesMixin *mixin = TP_PROPERTIES_MIXIN (obj);
TpPropertiesMixinClass *mixin_cls = TP_PROPERTIES_MIXIN_CLASS (
G_OBJECT_GET_CLASS (obj));
GPtrArray *prop_arr;
GValue prop_list = { 0, };
- TpIntSetFastIter iter;
+ TpIntsetFastIter iter;
guint len = tp_intset_size (props);
guint prop_id;
@@ -940,14 +940,14 @@ tp_properties_mixin_emit_changed (GObject *obj, const TpIntSet *props)
* added using their stored values.
*/
void
-tp_properties_mixin_emit_flags (GObject *obj, const TpIntSet *props)
+tp_properties_mixin_emit_flags (GObject *obj, const TpIntset *props)
{
TpPropertiesMixin *mixin = TP_PROPERTIES_MIXIN (obj);
TpPropertiesMixinClass *mixin_cls = TP_PROPERTIES_MIXIN_CLASS (
G_OBJECT_GET_CLASS (obj));
GPtrArray *prop_arr;
GValue prop_list = { 0, };
- TpIntSetFastIter iter;
+ TpIntsetFastIter iter;
guint len = tp_intset_size (props);
guint prop_id;
diff --git a/telepathy-glib/properties-mixin.h b/telepathy-glib/properties-mixin.h
index e3faa578a..1fd275de7 100644
--- a/telepathy-glib/properties-mixin.h
+++ b/telepathy-glib/properties-mixin.h
@@ -257,11 +257,11 @@ void tp_properties_context_return (TpPropertiesContext *ctx, GError *error);
gboolean tp_properties_context_return_if_done (TpPropertiesContext *ctx);
void tp_properties_mixin_change_value (GObject *obj, guint prop_id,
- const GValue *new_value, TpIntSet *props);
+ const GValue *new_value, TpIntset *props);
void tp_properties_mixin_change_flags (GObject *obj, guint prop_id,
- TpPropertyFlags add, TpPropertyFlags del, TpIntSet *props);
-void tp_properties_mixin_emit_changed (GObject *obj, const TpIntSet *props);
-void tp_properties_mixin_emit_flags (GObject *obj, const TpIntSet *props);
+ TpPropertyFlags add, TpPropertyFlags del, TpIntset *props);
+void tp_properties_mixin_emit_changed (GObject *obj, const TpIntset *props);
+void tp_properties_mixin_emit_flags (GObject *obj, const TpIntset *props);
gboolean tp_properties_mixin_is_readable (GObject *obj, guint prop_id);
gboolean tp_properties_mixin_is_writable (GObject *obj, guint prop_id);
diff --git a/tests/dbus/call-cancellation.c b/tests/dbus/call-cancellation.c
index cadf8ef98..2a50e241b 100644
--- a/tests/dbus/call-cancellation.c
+++ b/tests/dbus/call-cancellation.c
@@ -27,9 +27,9 @@ static TpDBusDaemon *i;
static TpDBusDaemon *j;
static TpDBusDaemon *k;
static TpDBusDaemon *z;
-static TpIntSet *method_ok;
-static TpIntSet *method_error;
-static TpIntSet *freed_user_data;
+static TpIntset *method_ok;
+static TpIntset *method_error;
+static TpIntset *freed_user_data;
static gpointer copy_of_d;
static gpointer copy_of_g;
static gpointer copy_of_h;
diff --git a/tests/dbus/callable-example.c b/tests/dbus/callable-example.c
index 6d0841bfb..fb53f71a5 100644
--- a/tests/dbus/callable-example.c
+++ b/tests/dbus/callable-example.c
@@ -48,10 +48,10 @@ test_assert_uu_hash_contains (GHashTable *hash,
typedef struct
{
- TpIntSet *added;
- TpIntSet *removed;
- TpIntSet *local_pending;
- TpIntSet *remote_pending;
+ TpIntset *added;
+ TpIntset *removed;
+ TpIntset *local_pending;
+ TpIntset *remote_pending;
GHashTable *details;
} GroupEvent;
diff --git a/tests/dbus/cli-group.c b/tests/dbus/cli-group.c
index 3f01a08f5..f7c2e7cff 100644
--- a/tests/dbus/cli-group.c
+++ b/tests/dbus/cli-group.c
@@ -83,7 +83,7 @@ test_channel_proxy (TpTestsTextChannelGroup *service_chan,
gboolean detailed,
gboolean properties)
{
- TpIntSet *add, *rem, *expected_members;
+ TpIntset *add, *rem, *expected_members;
GArray *arr, *yarr;
GError *error = NULL;
TpChannelGroupFlags flags;
@@ -333,7 +333,7 @@ check_removed_unknown_error_in_invalidated (void)
gchar *chan_path;
TpTestsTextChannelGroup *service_chan;
TpChannel *chan;
- TpIntSet *self_handle_singleton = tp_intset_new ();
+ TpIntset *self_handle_singleton = tp_intset_new ();
GHashTable *details = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
(GDestroyNotify) tp_g_value_slice_free);
gboolean invalidated = FALSE;
@@ -423,7 +423,7 @@ check_removed_known_error_in_invalidated (void)
gchar *chan_path;
TpTestsTextChannelGroup *service_chan;
TpChannel *chan;
- TpIntSet *self_handle_singleton = tp_intset_new ();
+ TpIntset *self_handle_singleton = tp_intset_new ();
GHashTable *details = g_hash_table_new_full (g_str_hash, g_str_equal, NULL,
(GDestroyNotify) tp_g_value_slice_free);
gboolean invalidated = FALSE;
diff --git a/tests/dbus/disconnection.c b/tests/dbus/disconnection.c
index 6e3d1323d..3ac70648f 100644
--- a/tests/dbus/disconnection.c
+++ b/tests/dbus/disconnection.c
@@ -24,8 +24,8 @@ static TpDBusDaemon *f;
static TpDBusDaemon *g;
static TpDBusDaemon *h;
static TpDBusDaemon *z;
-static TpIntSet *caught_signal;
-static TpIntSet *freed_user_data;
+static TpIntset *caught_signal;
+static TpIntset *freed_user_data;
enum {
TEST_A,
diff --git a/tests/dbus/group-mixin.c b/tests/dbus/group-mixin.c
index 3eca1f513..aa0d39da5 100644
--- a/tests/dbus/group-mixin.c
+++ b/tests/dbus/group-mixin.c
@@ -271,7 +271,7 @@ check_incoming_invitation (void)
/* We get an invitation to the channel */
{
- TpIntSet *add_local_pending = tp_intset_new ();
+ TpIntset *add_local_pending = tp_intset_new ();
tp_intset_add (add_local_pending, self_handle);
expect_signals ("HELLO THAR", 0, TP_CHANNEL_GROUP_CHANGE_REASON_INVITED,
@@ -386,7 +386,7 @@ in_the_desert (void)
/* A camel is approaching */
{
- TpIntSet *add = tp_intset_new ();
+ TpIntset *add = tp_intset_new ();
tp_intset_add (add, camel);
expect_signals ("", camel, TP_CHANNEL_GROUP_CHANGE_REASON_NONE,
@@ -402,7 +402,7 @@ in_the_desert (void)
/* A second camel is approaching (invited by the first camel) */
{
- TpIntSet *add = tp_intset_new ();
+ TpIntset *add = tp_intset_new ();
GHashTable *details = g_hash_table_new_full (g_str_hash, g_str_equal,
NULL, (GDestroyNotify) tp_g_value_slice_free);
@@ -423,7 +423,7 @@ in_the_desert (void)
}
{
- TpIntSet *del = tp_intset_new ();
+ TpIntset *del = tp_intset_new ();
GHashTable *details = g_hash_table_new_full (g_str_hash, g_str_equal,
NULL, (GDestroyNotify) tp_g_value_slice_free);
@@ -460,7 +460,7 @@ in_the_desert (void)
/* We and the second camel should be left in the channel */
{
- const TpIntSet *members = tp_channel_group_get_members (chan);
+ const TpIntset *members = tp_channel_group_get_members (chan);
GArray *service_members;
TpHandle a, b;
diff --git a/tests/dbus/handle-set.c b/tests/dbus/handle-set.c
index 43891a855..67e101700 100644
--- a/tests/dbus/handle-set.c
+++ b/tests/dbus/handle-set.c
@@ -17,7 +17,7 @@ main (int argc,
{
TpHandleRepoIface *repo = NULL;
TpHandleSet *set = NULL;
- TpIntSet *iset = NULL, *result = NULL;
+ TpIntset *iset = NULL, *result = NULL;
GError *error = NULL;
TpHandle h1, h2, h3, h4;
diff --git a/tests/intset.c b/tests/intset.c
index af79e0054..33a800dc4 100644
--- a/tests/intset.c
+++ b/tests/intset.c
@@ -3,9 +3,9 @@
#include <telepathy-glib/util.h>
static void
-iterate_in_order (TpIntSet *set)
+iterate_in_order (TpIntset *set)
{
- TpIntSetIter iter;
+ TpIntsetIter iter;
guint n = 0;
gint64 prev = (guint) -1;
@@ -26,9 +26,9 @@ iterate_in_order (TpIntSet *set)
}
static void
-iterate_fast (TpIntSet *set)
+iterate_fast (TpIntset *set)
{
- TpIntSetFastIter iter;
+ TpIntsetFastIter iter;
guint n = 0;
guint i;
@@ -44,7 +44,7 @@ iterate_fast (TpIntSet *set)
}
static void
-test_iteration (TpIntSet *set)
+test_iteration (TpIntset *set)
{
iterate_fast (set);
iterate_in_order (set);
@@ -52,13 +52,13 @@ test_iteration (TpIntSet *set)
int main (int argc, char **argv)
{
- TpIntSet *set1 = tp_intset_new ();
- TpIntSet *a, *b, *copy;
- TpIntSet *ab_union, *ab_expected_union;
- TpIntSet *ab_inter, *ab_expected_inter;
- TpIntSet *a_diff_b, *a_expected_diff_b;
- TpIntSet *b_diff_a, *b_expected_diff_a;
- TpIntSet *ab_symmdiff, *ab_expected_symmdiff;
+ TpIntset *set1 = tp_intset_new ();
+ TpIntset *a, *b, *copy;
+ TpIntset *ab_union, *ab_expected_union;
+ TpIntset *ab_inter, *ab_expected_inter;
+ TpIntset *a_diff_b, *a_expected_diff_b;
+ TpIntset *b_diff_a, *b_expected_diff_a;
+ TpIntset *ab_symmdiff, *ab_expected_symmdiff;
GValue *value;
g_type_init ();
@@ -191,7 +191,7 @@ int main (int argc, char **argv)
{
GArray *arr;
- TpIntSet *tmp;
+ TpIntset *tmp;
arr = tp_intset_to_array (a);
tmp = tp_intset_from_array (arr);
diff --git a/tests/lib/echo-cm.c b/tests/lib/echo-cm.c
index 6c84c5f42..3e34769b5 100644
--- a/tests/lib/echo-cm.c
+++ b/tests/lib/echo-cm.c
@@ -69,7 +69,7 @@ static const TpCMProtocolSpec example_protocols[] = {
static TpBaseConnection *
new_connection (TpBaseConnectionManager *self,
const gchar *proto,
- TpIntSet *params_present,
+ TpIntset *params_present,
gpointer parsed_params,
GError **error)
{
diff --git a/tests/lib/params-cm.c b/tests/lib/params-cm.c
index a0b1820cf..c8c1199bd 100644
--- a/tests/lib/params-cm.c
+++ b/tests/lib/params-cm.c
@@ -156,7 +156,7 @@ static const TpCMProtocolSpec example_protocols[] = {
static TpBaseConnection *
new_connection (TpBaseConnectionManager *self,
const gchar *proto,
- TpIntSet *params_present,
+ TpIntset *params_present,
gpointer parsed_params,
GError **error)
{
diff --git a/tests/lib/simple-manager.c b/tests/lib/simple-manager.c
index 31a88e828..27424ca05 100644
--- a/tests/lib/simple-manager.c
+++ b/tests/lib/simple-manager.c
@@ -70,7 +70,7 @@ static const TpCMProtocolSpec simple_protocols[] = {
static TpBaseConnection *
new_connection (TpBaseConnectionManager *self,
const gchar *proto,
- TpIntSet *params_present,
+ TpIntset *params_present,
gpointer parsed_params,
GError **error)
{
diff --git a/tests/lib/textchan-group.c b/tests/lib/textchan-group.c
index 6a6f5d7f3..bed655dac 100644
--- a/tests/lib/textchan-group.c
+++ b/tests/lib/textchan-group.c
@@ -76,7 +76,7 @@ add_member (GObject *obj,
GError **error)
{
TpTestsTextChannelGroup *self = TP_TESTS_TEXT_CHANNEL_GROUP (obj);
- TpIntSet *add = tp_intset_new ();
+ TpIntset *add = tp_intset_new ();
tp_intset_add (add, handle);
tp_group_mixin_change_members (obj, message, add, NULL, NULL, NULL,
diff --git a/telepathy-glib/channel-group.c b/telepathy-glib/channel-group.c
index 803c3457e..1b267d40c 100644
--- a/telepathy-glib/channel-group.c
+++ b/telepathy-glib/channel-group.c
@@ -110,7 +110,7 @@ tp_channel_group_get_flags (TpChannel *self)
* @self: a channel
*
* If @self is a group and the %TP_CHANNEL_FEATURE_GROUP feature has been
* prepared, return a #TpIntSet containing its members.
*
* If @self is a group but %TP_CHANNEL_FEATURE_GROUP has not been prepared,
* the result may either be a set of members, or %NULL.
@@ -120,7 +120,7 @@ tp_channel_group_get_flags (TpChannel *self)
* Returns: the members, or %NULL
* Since: 0.7.12
*/
-const TpIntSet *
+const TpIntset *
tp_channel_group_get_members (TpChannel *self)
{
g_return_val_if_fail (TP_IS_CHANNEL (self), NULL);
@@ -134,7 +134,7 @@ tp_channel_group_get_members (TpChannel *self)
* @self: a channel
*
* If @self is a group and the %TP_CHANNEL_FEATURE_GROUP feature has been
* prepared, return a #TpIntSet containing its local-pending members.
*
* If @self is a group but %TP_CHANNEL_FEATURE_GROUP has not been prepared,
* the result may either be a set of local-pending members, or %NULL.
@@ -144,7 +144,7 @@ tp_channel_group_get_members (TpChannel *self)
* Returns: the local-pending members, or %NULL
* Since: 0.7.12
*/
-const TpIntSet *
+const TpIntset *
tp_channel_group_get_local_pending (TpChannel *self)
{
g_return_val_if_fail (TP_IS_CHANNEL (self), NULL);
@@ -158,7 +158,7 @@ tp_channel_group_get_local_pending (TpChannel *self)
* @self: a channel
*
* If @self is a group and the %TP_CHANNEL_FEATURE_GROUP feature has been
* prepared, return a #TpIntSet containing its remote-pending members.
*
* If @self is a group but %TP_CHANNEL_FEATURE_GROUP has not been prepared,
* the result may either be a set of remote-pending members, or %NULL.
@@ -168,7 +168,7 @@ tp_channel_group_get_local_pending (TpChannel *self)
* Returns: the remote-pending members, or %NULL
* Since: 0.7.12
*/
-const TpIntSet *
+const TpIntset *
tp_channel_group_get_remote_pending (TpChannel *self)
{
g_return_val_if_fail (TP_IS_CHANNEL (self), NULL);
@@ -669,7 +669,7 @@ _tp_channel_emit_initial_sets (TpChannel *self)
{
GArray *added, *remote_pending;
GArray empty_array = { NULL, 0 };
- TpIntSetFastIter iter;
+ TpIntsetFastIter iter;
TpHandle handle;
tp_intset_fast_iter_init (&iter, self->priv->group_local_pending);
@@ -110,7 +110,7 @@ tp_channel_group_get_flags (TpChannel *self)
*
* If @self is a group and the %TP_CHANNEL_FEATURE_GROUP feature has been
- * prepared, return a #TpIntSet containing its members.
+ * prepared, return a #TpIntset containing its members.
*
* If @self is a group but %TP_CHANNEL_FEATURE_GROUP has not been prepared,
@@ -134,7 +134,7 @@ tp_channel_group_get_members (TpChannel *self)
*
* If @self is a group and the %TP_CHANNEL_FEATURE_GROUP feature has been
- * prepared, return a #TpIntSet containing its local-pending members.
+ * prepared, return a #TpIntset containing its local-pending members.
*
* If @self is a group but %TP_CHANNEL_FEATURE_GROUP has not been prepared,
@@ -158,7 +158,7 @@ tp_channel_group_get_local_pending (TpChannel *self)
*
* If @self is a group and the %TP_CHANNEL_FEATURE_GROUP feature has been
- * prepared, return a #TpIntSet containing its remote-pending members.
+ * prepared, return a #TpIntset containing its remote-pending members.
*
* If @self is a group but %TP_CHANNEL_FEATURE_GROUP has not been prepared,
diff --git a/telepathy-glib/group-mixin.c b/telepathy-glib/group-mixin.c
index 412945835..84aad8271 100644
--- a/telepathy-glib/group-mixin.c
+++ b/telepathy-glib/group-mixin.c
@@ -1337,7 +1337,7 @@ local_pending_added_foreach (guint i,
static void
local_pending_added (TpGroupMixin *mixin,
- const TpIntSet *added,
+ const TpIntset *added,
TpHandle actor,
guint reason,
const gchar *message)
@@ -1363,7 +1363,7 @@ local_pending_remove_foreach (guint i,
static void
local_pending_remove (TpGroupMixin *mixin,
- TpIntSet *removed)
+ TpIntset *removed)
{
tp_intset_foreach (removed, local_pending_remove_foreach, mixin);
}
@@ -1514,16 +1514,16 @@ emit_members_changed_signals (GObject *channel,
static gboolean
change_members (GObject *obj,
const gchar *message,
- const TpIntSet *add,
- const TpIntSet *del,
- const TpIntSet *add_local_pending,
- const TpIntSet *add_remote_pending,
+ const TpIntset *add,
+ const TpIntset *del,
+ const TpIntset *add_local_pending,
+ const TpIntset *add_remote_pending,
TpHandle actor,
TpChannelGroupChangeReason reason,
const GHashTable *details)
{
TpGroupMixin *mixin = TP_GROUP_MIXIN (obj);
- TpIntSet *new_add, *new_remove, *new_local_pending,
+ TpIntset *new_add, *new_remove, *new_local_pending,
*new_remote_pending, *tmp, *tmp2, *empty;
gboolean ret;
@@ -1711,7 +1711,7 @@ change_members (GObject *obj,
* If any two of add, del, add_local_pending and add_remote_pending have
* a non-empty intersection, the result is undefined. Don't do that.
*
* Each of the TpIntSet arguments may be %NULL, which is treated as
* equivalent to an empty set.
*
* Returns: %TRUE if the group was changed and the MembersChanged(Detailed)
@@ -1721,10 +1721,10 @@ change_members (GObject *obj,
gboolean
tp_group_mixin_change_members (GObject *obj,
const gchar *message,
- const TpIntSet *add,
- const TpIntSet *del,
- const TpIntSet *add_local_pending,
- const TpIntSet *add_remote_pending,
+ const TpIntset *add,
+ const TpIntset *del,
+ const TpIntset *add_local_pending,
+ const TpIntset *add_remote_pending,
TpHandle actor,
TpChannelGroupChangeReason reason)
{
@@ -1782,7 +1782,7 @@ tp_group_mixin_change_members (GObject *obj,
* If any two of add, del, add_local_pending and add_remote_pending have
* a non-empty intersection, the result is undefined. Don't do that.
*
* Each of the TpIntSet arguments may be %NULL, which is treated as
* equivalent to an empty set.
*
* details may contain, among other entries, the well-known
@@ -1808,10 +1808,10 @@ tp_group_mixin_change_members (GObject *obj,
*/
gboolean
tp_group_mixin_change_members_detailed (GObject *obj,
- const TpIntSet *add,
- const TpIntSet *del,
- const TpIntSet *add_local_pending,
- const TpIntSet *add_remote_pending,
+ const TpIntset *add,
+ const TpIntset *del,
+ const TpIntset *add_local_pending,
+ const TpIntset *add_remote_pending,
const GHashTable *details)
{
const gchar *message;
@@ -1711,7 +1711,7 @@ change_members (GObject *obj,
* a non-empty intersection, the result is undefined. Don't do that.
*
- * Each of the TpIntSet arguments may be %NULL, which is treated as
+ * Each of the TpIntset arguments may be %NULL, which is treated as
* equivalent to an empty set.
*
@@ -1782,7 +1782,7 @@ tp_group_mixin_change_members (GObject *obj,
* a non-empty intersection, the result is undefined. Don't do that.
*
- * Each of the TpIntSet arguments may be %NULL, which is treated as
+ * Each of the TpIntset arguments may be %NULL, which is treated as
* equivalent to an empty set.
*